orca r3869 - in trunk: . src/orca test/keystrokes/firefox



Author: joanied
Date: Wed Apr 30 19:18:31 2008
New Revision: 3869
URL: http://svn.gnome.org/viewvc/orca?rev=3869&view=rev

Log:
* src/orca/Gecko.py:
  src/orca/where_am_I.py:
  Fix for bug #517736 - whereAmI does not handle text with
  embedded object characters

* test/keystrokes/firefox/moz_menu.py:
  test/keystrokes/firefox/bug_512303.py:
  test/keystrokes/firefox/line_nav_imagemap.py:
  test/keystrokes/firefox/dojo_slider.py:
  test/keystrokes/firefox/uiuc_button.py:
  test/keystrokes/firefox/xul_role_menu_bar.py:
  test/keystrokes/firefox/xul_role_list_item.py:
  test/keystrokes/firefox/xul_role_radio_button.py:
  test/keystrokes/firefox/label_guess_bugzilla_search.py:
  test/keystrokes/firefox/xul_role_tree.py:
  test/keystrokes/firefox/xul_role_entry.py:
  test/keystrokes/firefox/dojo_tree.py:
  test/keystrokes/firefox/html_role_combo_box.py:
  test/keystrokes/firefox/xul_where_am_i_status_bar.py:
  test/keystrokes/firefox/moz_progressbar.py:
  test/keystrokes/firefox/line_nav_wiki.py:
  test/keystrokes/firefox/xul_role_tree_table.py:
  test/keystrokes/firefox/html_struct_nav_large_obj.py:
  test/keystrokes/firefox/line_nav_multi_line_text.py:
  test/keystrokes/firefox/uiuc_tree.py:
  test/keystrokes/firefox/dojo_tabcontainer.py:
  test/keystrokes/firefox/page_summary.py:
  test/keystrokes/firefox/line_nav_heading_section.py:
  test/keystrokes/firefox/line_nav_table_cell_links.py:
  test/keystrokes/firefox/line_nav_empty_anchor.py:
  test/keystrokes/firefox/html_struct_nav_blockquote.py:
  test/keystrokes/firefox/xul_where_am_i_dialog.py:
  test/keystrokes/firefox/line_nav_bugzilla_search.py:
  test/keystrokes/firefox/uiuc_grid.py:
  test/keystrokes/firefox/xul_role_page_tab.py:
  test/keystrokes/firefox/html_struct_nav_links.py:
  test/keystrokes/firefox/xul_role_alert.py:
  test/keystrokes/firefox/xul_role_combo_box.py:
  test/keystrokes/firefox/line_nav_enter_bug.py:
  test/keystrokes/firefox/line_nav_simple_form.py:
  test/keystrokes/firefox/line_nav_nested_tables.py:
  Updated all of the regression tests to be consistent with the
  current state of affairs (latest Orca and latest FF3 from trunk).


Modified:
   trunk/ChangeLog
   trunk/src/orca/Gecko.py
   trunk/src/orca/where_am_I.py
   trunk/test/keystrokes/firefox/bug_512303.py
   trunk/test/keystrokes/firefox/dojo_slider.py
   trunk/test/keystrokes/firefox/dojo_tabcontainer.py
   trunk/test/keystrokes/firefox/dojo_tree.py
   trunk/test/keystrokes/firefox/html_role_combo_box.py
   trunk/test/keystrokes/firefox/html_struct_nav_blockquote.py
   trunk/test/keystrokes/firefox/html_struct_nav_large_obj.py
   trunk/test/keystrokes/firefox/html_struct_nav_links.py
   trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py
   trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py
   trunk/test/keystrokes/firefox/line_nav_empty_anchor.py
   trunk/test/keystrokes/firefox/line_nav_enter_bug.py
   trunk/test/keystrokes/firefox/line_nav_heading_section.py
   trunk/test/keystrokes/firefox/line_nav_imagemap.py
   trunk/test/keystrokes/firefox/line_nav_multi_line_text.py
   trunk/test/keystrokes/firefox/line_nav_nested_tables.py
   trunk/test/keystrokes/firefox/line_nav_simple_form.py
   trunk/test/keystrokes/firefox/line_nav_table_cell_links.py
   trunk/test/keystrokes/firefox/line_nav_wiki.py
   trunk/test/keystrokes/firefox/moz_menu.py
   trunk/test/keystrokes/firefox/moz_progressbar.py
   trunk/test/keystrokes/firefox/page_summary.py
   trunk/test/keystrokes/firefox/uiuc_button.py
   trunk/test/keystrokes/firefox/uiuc_grid.py
   trunk/test/keystrokes/firefox/uiuc_tree.py
   trunk/test/keystrokes/firefox/xul_role_alert.py
   trunk/test/keystrokes/firefox/xul_role_combo_box.py
   trunk/test/keystrokes/firefox/xul_role_entry.py
   trunk/test/keystrokes/firefox/xul_role_list_item.py
   trunk/test/keystrokes/firefox/xul_role_menu_bar.py
   trunk/test/keystrokes/firefox/xul_role_page_tab.py
   trunk/test/keystrokes/firefox/xul_role_radio_button.py
   trunk/test/keystrokes/firefox/xul_role_tree.py
   trunk/test/keystrokes/firefox/xul_role_tree_table.py
   trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py
   trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py

Modified: trunk/src/orca/Gecko.py
==============================================================================
--- trunk/src/orca/Gecko.py	(original)
+++ trunk/src/orca/Gecko.py	Wed Apr 30 19:18:31 2008
@@ -1408,6 +1408,36 @@
             else:
                 self._iterativePageSummary(obj)
 
+    def _speakText(self, obj, basicOnly):
+        """Speaks the line if the current line contains embedded object
+        characters; otherwise calls the parent class.
+        """
+
+        line = self._script.currentLineContents
+        if not self._script.inDocumentContent(obj) \
+           or not line or len(line) == 1:
+            return where_am_I.WhereAmI._speakText(self, obj, basicOnly)
+
+        cell = self._script.getAncestor(obj,
+                                        [pyatspi.ROLE_TABLE_CELL],
+                                        [pyatspi.ROLE_DOCUMENT_FRAME])
+        if cell:
+            return self._speakTableCell(cell, basicOnly)
+
+        utterances = []
+        text = self._getObjLabel(obj)
+        utterances.append(text)
+
+        if obj.getRole() == pyatspi.ROLE_LINK:
+            text = rolenames.getSpeechForRoleName(obj.parent)
+        else:
+            text = rolenames.getSpeechForRoleName(obj)
+        
+        utterances.append(text)
+        
+        speech.speakUtterances(utterances)
+        self._script.speakContents(line)
+
     def _speakDefaultButton(self, obj):
         """Speaks the default button in a dialog.
 
@@ -1963,7 +1993,7 @@
         # getLineContentsAtOffset() twice.
         #
         self._previousLineContents = None
-        self._currentLineContents = None
+        self.currentLineContents = None
         self._nextLineContents = None
 
         # Last focused frame. We are only interested in frame focused events
@@ -4461,22 +4491,22 @@
         - offset: the character offset within obj
         """
 
-        index = self.findObjectOnLine(obj, offset, self._currentLineContents)
+        index = self.findObjectOnLine(obj, offset, self.currentLineContents)
         if index < 0:
             index = self.findObjectOnLine(obj, 
                                           offset, 
                                           self._previousLineContents)
             if index >= 0:
-                self._nextLineContents = self._currentLineContents
-                self._currentLineContents = self._previousLineContents
+                self._nextLineContents = self.currentLineContents
+                self.currentLineContents = self._previousLineContents
                 self._previousLineContents = None
             else:
                 index = self.findObjectOnLine(obj, 
                                               offset, 
                                               self._nextLineContents)
                 if index >= 0:
-                    self._previousLineContents = self._currentLineContents
-                    self._currentLineContents = self._nextLineContents
+                    self._previousLineContents = self.currentLineContents
+                    self.currentLineContents = self._nextLineContents
                     self._nextLineContents = None
                 else:
                     self._destroyLineCache()
@@ -4485,7 +4515,7 @@
         """Removes all of the stored lines."""
 
         self._previousLineContents = None
-        self._currentLineContents = None
+        self.currentLineContents = None
         self._nextLineContents = None
 
     def presentLine(self, obj, offset):
@@ -4496,12 +4526,12 @@
         - offset: the offset within obj
         """
 
-        contents = self._currentLineContents
+        contents = self.currentLineContents
         index = self.findObjectOnLine(obj, offset, contents)
         if index < 0:
-            self._currentLineContents = self.getLineContentsAtOffset(obj,
+            self.currentLineContents = self.getLineContentsAtOffset(obj,
                                                                      offset)
-        self.speakContents(self._currentLineContents)
+        self.speakContents(self.currentLineContents)
         self.updateBraille(obj)
 
     def updateBraille(self, obj, extraRegion=None):
@@ -4546,14 +4576,14 @@
                 lineContentsOffset = max(0, focusedCharacterOffset - 1)
                 needToRefresh = True
 
-        contents = self._currentLineContents
+        contents = self.currentLineContents
         index = self.findObjectOnLine(focusedObj, 
                                       max(0, lineContentsOffset),
                                       contents)
         if index < 0 or needToRefresh:
             contents = self.getLineContentsAtOffset(focusedObj,
                                                     max(0, lineContentsOffset))
-            self._currentLineContents = contents
+            self.currentLineContents = contents
 
         if not len(contents):
             return
@@ -6253,7 +6283,7 @@
         extents = obj.queryComponent().getExtents(0)
         objExtents = [extents.x, extents.y, extents.width, extents.height]
 
-        lineContents = self._currentLineContents
+        lineContents = self.currentLineContents
         ourIndex = self.findObjectOnLine(obj, 0, lineContents)
         if ourIndex < 0:
             lineContents = self.getLineContentsAtOffset(obj, 0)
@@ -6398,7 +6428,7 @@
         objExtents = \
                [extents.x, extents.y, extents.width, extents.height]
 
-        index = self.findObjectOnLine(obj, 0, self._currentLineContents)
+        index = self.findObjectOnLine(obj, 0, self.currentLineContents)
         if index > 0 and self._previousLineContents:
             prevLineContents = self._previousLineContents
             prevObj = prevLineContents[0][0]
@@ -8341,7 +8371,7 @@
         if not obj:
             return self.getTopOfFile()
 
-        currentLine = self._currentLineContents
+        currentLine = self.currentLineContents
         index = self.findObjectOnLine(obj, characterOffset, currentLine)
         if index < 0:
             currentLine = self.getLineContentsAtOffset(obj, characterOffset)
@@ -8406,8 +8436,8 @@
                     break
 
         if updateCache:
-            self._nextLineContents = self._currentLineContents
-            self._currentLineContents = prevLine
+            self._nextLineContents = self.currentLineContents
+            self.currentLineContents = prevLine
 
         return [prevObj, prevOffset]
 
@@ -8430,7 +8460,7 @@
         if not obj:
             return self.getBottomOfFile()
 
-        currentLine = self._currentLineContents
+        currentLine = self.currentLineContents
         index = self.findObjectOnLine(obj, characterOffset, currentLine)
         if index < 0:
             currentLine = self.getLineContentsAtOffset(obj, characterOffset)
@@ -8495,8 +8525,8 @@
                     break
 
         if updateCache:
-            self._previousLineContents = self._currentLineContents
-            self._currentLineContents = nextLine
+            self._previousLineContents = self.currentLineContents
+            self.currentLineContents = nextLine
 
         return [nextObj, nextOffset]
 
@@ -8939,14 +8969,14 @@
         if obj and obj.getState().contains(pyatspi.STATE_SELECTABLE):
             obj = obj.parent.parent
             characterOffset = self.getCharacterOffsetInParent(obj)
-            self._currentLineContents = None
+            self.currentLineContents = None
 
         characterOffset = max(0, characterOffset)
         [prevObj, prevOffset] = [obj, characterOffset]
         found = False
         mayHaveGoneTooFar = False
 
-        line = self._currentLineContents \
+        line = self.currentLineContents \
                or self.getLineContentsAtOffset(obj, characterOffset)
         startingPoint = line
         useful = self.getMeaningfulObjectsFromLine(line)
@@ -8985,11 +9015,11 @@
             if not found:
                 self._nextLineContents = line
                 prevLine = self.findPreviousLine(line[0][0], line[0][1])
-                line = self._currentLineContents
+                line = self.currentLineContents
                 useful = self.getMeaningfulObjectsFromLine(line)
                 prevObj = useful[-1][0]
                 prevOffset = useful[-1][1]
-                if self._currentLineContents == self._nextLineContents:
+                if self.currentLineContents == self._nextLineContents:
                     break
 
         if not found:
@@ -9014,7 +9044,7 @@
                 prevOffset = useful[index][1]
 
         if found:
-            self._currentLineContents = line
+            self.currentLineContents = line
             self.setCaretPosition(prevObj, prevOffset)
             self.updateBraille(prevObj)
             objectContents = self.getObjectContentsAtOffset(prevObj,
@@ -9032,13 +9062,13 @@
         if obj and obj.getState().contains(pyatspi.STATE_SELECTABLE):
             obj = obj.parent.parent
             characterOffset = self.getCharacterOffsetInParent(obj)
-            self._currentLineContents = None
+            self.currentLineContents = None
 
         characterOffset = max(0, characterOffset)
         [nextObj, nextOffset] = [obj, characterOffset]
         found = False
 
-        line = self._currentLineContents \
+        line = self.currentLineContents \
                or self.getLineContentsAtOffset(obj, characterOffset)
 
         while line and not found:
@@ -9056,8 +9086,8 @@
                 self._previousLineContents = line
                 [nextObj, nextOffset] = self.findNextLine(line[-1][0], 
                                                           line[-1][2])
-                line = self._currentLineContents
-                if self._currentLineContents == self._previousLineContents:
+                line = self.currentLineContents
+                if self.currentLineContents == self._previousLineContents:
                     break
 
         if not found:
@@ -9077,7 +9107,7 @@
             found = not (nextObj is None)
 
         if found:
-            self._currentLineContents = line
+            self.currentLineContents = line
             self.setCaretPosition(nextObj, nextOffset)
             self.updateBraille(nextObj)
             objectContents = self.getObjectContentsAtOffset(nextObj,

Modified: trunk/src/orca/where_am_I.py
==============================================================================
--- trunk/src/orca/where_am_I.py	(original)
+++ trunk/src/orca/where_am_I.py	Wed Apr 30 19:18:31 2008
@@ -127,7 +127,10 @@
         elif role == pyatspi.ROLE_LIST_ITEM:
             self._speakListItem(obj, basicOnly)
 
-        elif role == pyatspi.ROLE_PARAGRAPH:
+        elif role in [pyatspi.ROLE_PARAGRAPH,
+                      pyatspi.ROLE_SECTION,
+                      pyatspi.ROLE_HEADING,
+                      pyatspi.ROLE_DOCUMENT_FRAME]:
             self._speakParagraph(obj, basicOnly)
 
         elif role == pyatspi.ROLE_ICON:
@@ -716,8 +719,9 @@
         if link_uri:
             link_uri_info = urlparse.urlparse(link_uri)
         else:
-            # something is wrong, just return
-            return
+            # It might be an anchor.  Try to speak the text.
+            #
+            return self._speakText(obj, basicOnly)
       
         # Try to get the URI of the active document and parse it
         doc_uri = self._script.getDocumentFrameURI()

Modified: trunk/test/keystrokes/firefox/bug_512303.py
==============================================================================
--- trunk/test/keystrokes/firefox/bug_512303.py	(original)
+++ trunk/test/keystrokes/firefox/bug_512303.py	Wed Apr 30 19:18:31 2008
@@ -42,8 +42,12 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'this is a caption for this table Caption'",
+    ["BUG? - For some reason we're repeating ourselves",
+     "BRAILLE LINE:  'this is a caption for this table Caption'",
+     "     VISIBLE:  'this is a caption for this table', cursor=1",
+     "BRAILLE LINE:  'this is a caption for this table Caption'",
      "     VISIBLE:  'this is a caption for this table', cursor=1",
+     "SPEECH OUTPUT: 'this is a caption for this table caption'",
      "SPEECH OUTPUT: 'this is a caption for this table caption'"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/dojo_slider.py
==============================================================================
--- trunk/test/keystrokes/firefox/dojo_slider.py	(original)
+++ trunk/test/keystrokes/firefox/dojo_slider.py	Wed Apr 30 19:18:31 2008
@@ -200,9 +200,9 @@
 sequence.append(utils.AssertPresentationAction(
     "move to entry", 
     ["BUG? - We're not guessing the label",
-     "BRAILLE LINE:  '10.0% $l Slider1 Value: 10.0% $l'",
+     "BRAILLE LINE:  'Slider1 Value: 10.0% $l'",
      "     VISIBLE:  'Slider1 Value: 10.0% $l', cursor=21",
-     "BRAILLE LINE:  '10.0% $l Slider1 Value: 10.0% $l'",
+     "BRAILLE LINE:  'Slider1 Value: 10.0% $l'",
      "     VISIBLE:  'Slider1 Value: 10.0% $l', cursor=21",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'text 10.0%'"]))

Modified: trunk/test/keystrokes/firefox/dojo_tabcontainer.py
==============================================================================
--- trunk/test/keystrokes/firefox/dojo_tabcontainer.py	(original)
+++ trunk/test/keystrokes/firefox/dojo_tabcontainer.py	Wed Apr 30 19:18:31 2008
@@ -27,7 +27,7 @@
 ########################################################################
 # Give the widget a moment to construct itself
 #
-sequence.append(PauseAction(3000))
+sequence.append(PauseAction(5000))
 
 ########################################################################
 # Tab to 'Tab 2'.  

Modified: trunk/test/keystrokes/firefox/dojo_tree.py
==============================================================================
--- trunk/test/keystrokes/firefox/dojo_tree.py	(original)
+++ trunk/test/keystrokes/firefox/dojo_tree.py	Wed Apr 30 19:18:31 2008
@@ -66,12 +66,11 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "basic whereAmI", 
-    ["BUG? - We aren't getting the correct item count",
-     "BRAILLE LINE:  'Africa ListItem'",
+    ["BRAILLE LINE:  'Africa ListItem'",
      "     VISIBLE:  'Africa ListItem', cursor=1",
      "SPEECH OUTPUT: 'list item'",
      "SPEECH OUTPUT: 'Africa'",
-     "SPEECH OUTPUT: 'item 1 of 6'",
+     "SPEECH OUTPUT: 'item 1 of 1'",
      "SPEECH OUTPUT: 'collapsed'",
      "SPEECH OUTPUT: 'tree level 2'"]))
 

Modified: trunk/test/keystrokes/firefox/html_role_combo_box.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_role_combo_box.py	(original)
+++ trunk/test/keystrokes/firefox/html_role_combo_box.py	Wed Apr 30 19:18:31 2008
@@ -40,6 +40,20 @@
      "SPEECH OUTPUT: 'Severity link : Severity normal combo box'"]))
 
 ########################################################################
+# Press Tab once to get to the Severity link. 
+#
+sequence.append(utils.StartRecordingAction())
+sequence.append(KeyComboAction("Tab"))
+sequence.append(utils.AssertPresentationAction(
+    "Tab to Severity combo box", 
+    ["BRAILLE LINE:  'Severity Link : Severity normal Combo'",
+     "     VISIBLE:  'Severity Link : Severity normal ', cursor=1",
+     "BRAILLE LINE:  'Severity Link : Severity normal Combo'",
+     "     VISIBLE:  'Severity Link : Severity normal ', cursor=1",
+     "SPEECH OUTPUT: ''",
+     "SPEECH OUTPUT: 'Severity link'"]))
+
+########################################################################
 # Press Tab once to get to the Severity combo box.  This combo box
 # has a proper label (the Severity link that precedes it).
 #
@@ -48,16 +62,14 @@
 sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(utils.AssertPresentationAction(
     "Tab to Severity combo box", 
-    ["BUG? - For some reason we're also speaking the link that precedes the combo box",
-     "BRAILLE LINE:  'Severity Link : Severity normal Combo'",
+    ["BRAILLE LINE:  'Severity Link : Severity normal Combo'",
      "     VISIBLE:  'normal Combo', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Severity normal combo box'"]))
 
 ########################################################################
 # Press Tab twice to get to the Priority combo box.  This combo box
-# lacks a proper label. Label guess should guess "Priority" from the
-# link that precedes it.
+# lacks a proper label. 
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
@@ -81,69 +93,30 @@
      "SPEECH OUTPUT: 'Normal combo box'"]))
 
 ########################################################################
-# Press Tab once to get to the Resolution combo box.  This combo box
-# lacks a proper label. Label guess should guess "Resolution" from the
-# text above it. 
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Tab"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
-sequence.append(utils.AssertPresentationAction(
-    "Tab to Resolution combo box", 
-    ["BRAILLE LINE:  'FIXED Combo'",
-     "     VISIBLE:  'FIXED Combo', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Resolution: FIXED combo box'"]))
-
-########################################################################
-# Press Down Arrow to change the selection to WONTFIX.  
+# Press Down Arrow to change the selection to Low.  
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
-    "Change selection Down: WONTFIX",
+    "Change selection Down: Low",
     ["BUG? - We're picking up the previous menu item in the braille context",
-     "BRAILLE LINE:  'FIXED Combo WONTFIX'",
-     "     VISIBLE:  'FIXED Combo WONTFIX', cursor=13",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'WONTFIX'"]))
-
-########################################################################
-# Press Down Arrow to change the selection to NOTABUG
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Down"))
-sequence.append(utils.AssertPresentationAction(
-    "Change selection Down: NOTABUG", 
-    ["BRAILLE LINE:  'WONTFIX Combo NOTABUG'",
-     "     VISIBLE:  'WONTFIX Combo NOTABUG', cursor=15",
+     "BRAILLE LINE:  'Normal Combo Low'",
+     "     VISIBLE:  'Normal Combo Low', cursor=14",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'NOTABUG'"]))
+     "SPEECH OUTPUT: 'Low'"]))
 
 ########################################################################
-# Press Up Arrow to change the selection back to WONTFIX.
+# Press Up Arrow to change the selection back to Normal.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
-    "Change selection Up: WONTFIX",
+    "Change selection Up: Normal",
     ["BUG? - We're picking up the previous menu item in the braille context",
-     "BRAILLE LINE:  'FIXED Combo WONTFIX'",
-     "     VISIBLE:  'FIXED Combo WONTFIX', cursor=13",
+     "BRAILLE LINE:  'High Combo Normal'",
+     "     VISIBLE:  'High Combo Normal', cursor=12",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'WONTFIX'"]))
-
-########################################################################
-# Press Up Arrow to change the selection back to FIXED.
-#
-sequence.append(utils.StartRecordingAction())
-sequence.append(KeyComboAction("Up"))
-sequence.append(utils.AssertPresentationAction(
-    "Change selection Up: FIXED", 
-    ["BRAILLE LINE:  'FIXED'",
-     "     VISIBLE:  'FIXED', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'FIXED'"]))
+     "SPEECH OUTPUT: 'Normal'"]))
 
 ########################################################################
 # Press Alt Down Arrow to expand the combo box.  
@@ -152,88 +125,96 @@
 sequence.append(KeyComboAction("<Alt>Down"))
 sequence.append(utils.AssertPresentationAction(
     "Alt Down to Expand",
-    ["BRAILLE LINE:  'FIXED Combo'",
-     "     VISIBLE:  'FIXED Combo', cursor=1",
-     "BRAILLE LINE:  'FIXED'",
-     "     VISIBLE:  'FIXED', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'FIXED combo box'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'FIXED'"]))
+    ["BRAILLE LINE:  'Priority Link : Normal Combo'",
+     "     VISIBLE:  'Priority Link : Normal Combo', cursor=17",
+     "BRAILLE LINE:  'Normal'",
+     "     VISIBLE:  'Normal', cursor=1",
+     "SPEECH OUTPUT: ''",
+     "SPEECH OUTPUT: 'Normal combo box'",
+     "SPEECH OUTPUT: ''",
+     "SPEECH OUTPUT: 'Normal'"]))
 
 ########################################################################
-# Press Down Arrow to change the selection back to WONTFIX.
+# Press Down Arrow to change the selection back to Low.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
-    "Change selection Down: WONTFIX",
-    ["BRAILLE LINE:  'WONTFIX'",
-     "     VISIBLE:  'WONTFIX', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'WONTFIX'"]))
+    "Change selection Down: Low",
+    ["BRAILLE LINE:  'Low'",
+     "     VISIBLE:  'Low', cursor=1",
+     "SPEECH OUTPUT: ''",
+     "SPEECH OUTPUT: 'Low'"]))
 
 ########################################################################
-# Press Return to collapse the combo box with WONTFIX selected.
+# Press Return to collapse the combo box with Low selected.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Return"))
 sequence.append(utils.AssertPresentationAction(
     "Return to collapse combo box",
-    ["BRAILLE LINE:  'WONTFIX Combo'",
-     "     VISIBLE:  'WONTFIX Combo', cursor=1",
+    ["BRAILLE LINE:  'Priority Link : Low Combo'",
+     "     VISIBLE:  'Priority Link : Low Combo', cursor=17",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Resolution: WONTFIX combo box'"]))
+     "SPEECH OUTPUT: 'Low combo box'"]))
 
 ########################################################################
-# Press Tab once to get to the Version combo box.  This combo box
-# lacks a proper label. Label guess should guess "Version" from the
-# text in the table cell on the left.
+# Press Tab once to get to the Resolution combo box.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(utils.AssertPresentationAction(
     "Tab",
-    ["BRAILLE LINE:  'Version 2.16 Combo'",
-     "     VISIBLE:  'Version 2.16 Combo', cursor=9",
+    ["BRAILLE LINE:  'FIXED Combo'",
+     "     VISIBLE:  'FIXED Combo', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Version 2.16 combo box'"]))
+     "SPEECH OUTPUT: 'Resolution: FIXED combo box'"]))
 
 ########################################################################
-# Press Left Arrow once to move off of this combo box and onto the
-# 'n' at the end of "Version".
+# Press Left Arrow once to move off of this combo box.
 # 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Left"))
 sequence.append(utils.AssertPresentationAction(
     "Left out of combo box", 
+    ["BRAILLE LINE:  'FIXED Combo'",
+     "     VISIBLE:  'FIXED Combo', cursor=0",
+     "SPEECH OUTPUT: 'Resolution: FIXED combo box'"]))
+
+########################################################################
+# Press Down Arrow once to move to the next line.
+#
+sequence.append(utils.StartRecordingAction())
+sequence.append(KeyComboAction("Down"))
+sequence.append(utils.AssertPresentationAction(
+    "Line Down",
     ["BRAILLE LINE:  'Version 2.16 Combo'",
-     "     VISIBLE:  'Version 2.16 Combo', cursor=0",
+     "     VISIBLE:  'Version 2.16 Combo', cursor=1",
      "SPEECH OUTPUT: 'Version 2.16 combo box'"]))
 
 ########################################################################
-# Press Down Arrow once to move to the next line which contains
-# the text "Component" in a table cell.
+# Press Down Arrow again to move to the next line which contains the
+# word Component.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
-    "Line Down to Component",
+    "Line Down", 
     ["BRAILLE LINE:  'Component'",
      "     VISIBLE:  'Component', cursor=1",
      "SPEECH OUTPUT: 'Component'"]))
 
 ########################################################################
-# Press Down Arrow again to move to the next line which contains
-# a combo box.
+# Press Down Arrow again to move to the next line which contains a
+# combo box.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down", 
-    ["BRAILLE LINE:  'Speech Combo'",
-     "     VISIBLE:  'Speech Combo', cursor=0",
+    ["BRAILLE LINE:  'Speech Combo'",
+     "     VISIBLE:  'Speech Combo', cursor=0",
      "SPEECH OUTPUT: 'Speech combo box'"]))
 
 ########################################################################
@@ -244,29 +225,29 @@
 sequence.append(KeyComboAction("<Alt>Down"))
 sequence.append(utils.AssertPresentationAction(
     "Alt Down to Expand", 
-    ["BRAILLE LINE:  'Speech Combo'",
-     "     VISIBLE:  'Speech Combo', cursor=1",
-     "BRAILLE LINE:  'Speech'",
-     "     VISIBLE:  'Speech', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Speech combo box'",
-     "SPEECH OUTPUT: ''",
+    ["BRAILLE LINE:  'Speech Combo'",
+     "     VISIBLE:  'Speech Combo', cursor=1",
+     "BRAILLE LINE:  'Speech'",
+     "     VISIBLE:  'Speech', cursor=1",
+     "SPEECH OUTPUT: ''",
+     "SPEECH OUTPUT: 'Speech combo box'",
+     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Speech'"]))
 
 ########################################################################
-# Press Down Arrow to change the selection to Braille.
+# Press Down Arrow to change the selection.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
-    "Change selection Down: Braille", 
-    ["BRAILLE LINE:  'Braille'",
-     "     VISIBLE:  'Braille', cursor=1",
-     "SPEECH OUTPUT: ''",
+    "Change selection Down", 
+    ["BRAILLE LINE:  'Braille'",
+     "     VISIBLE:  'Braille', cursor=1",
+     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Braille'"]))
 
 ########################################################################
-# Press Return to collapse the combo box with Braille selected.
+# Press Return to collapse the combo box.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Return"))
@@ -285,12 +266,12 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Braille Combo'",
-     "     VISIBLE:  'Braille Combo', cursor=1",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'combo box'",
-     "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: ''",
+    ["BRAILLE LINE:  'Braille Combo'",
+     "     VISIBLE:  'Braille Combo', cursor=1",
+     "SPEECH OUTPUT: ''",
+     "SPEECH OUTPUT: 'combo box'",
+     "SPEECH OUTPUT: ''",
+     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: ''"]))
 
 ########################################################################

Modified: trunk/test/keystrokes/firefox/html_struct_nav_blockquote.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_struct_nav_blockquote.py	(original)
+++ trunk/test/keystrokes/firefox/html_struct_nav_blockquote.py	Wed Apr 30 19:18:31 2008
@@ -51,6 +51,8 @@
     "q to first quote", 
     ["BRAILLE LINE:  'NOBODY expects the Spanish Inquisition! Our chief weapon is surprise. Surprise and fear. Fear and surprise. Our two weapons are fear and'",
      "     VISIBLE:  'NOBODY expects the Spanish Inqui', cursor=1",
+     "BRAILLE LINE:  'NOBODY expects the Spanish Inquisition! Our chief weapon is surprise. Surprise and fear. Fear and surprise. Our two weapons are fear and'",
+     "     VISIBLE:  'NOBODY expects the Spanish Inqui', cursor=1",
      "SPEECH OUTPUT: 'NOBODY expects the Spanish Inquisition! Our chief weapon is surprise. Surprise and fear. Fear and surprise. Our two weapons are fear and'"]))
 
 ########################################################################

Modified: trunk/test/keystrokes/firefox/html_struct_nav_large_obj.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_struct_nav_large_obj.py	(original)
+++ trunk/test/keystrokes/firefox/html_struct_nav_large_obj.py	Wed Apr 30 19:18:31 2008
@@ -47,6 +47,8 @@
     "First large chunk", 
     ["BRAILLE LINE:  'I have of late but'",
      "     VISIBLE:  'I have of late but', cursor=1",
+     "BRAILLE LINE:  'I have of late but'",
+     "     VISIBLE:  'I have of late but', cursor=1",
      "SPEECH OUTPUT: 'I have of late but",
      "wherefore I know not lost all my mirth,",
      "forgone all custom of exercises;",

Modified: trunk/test/keystrokes/firefox/html_struct_nav_links.py
==============================================================================
--- trunk/test/keystrokes/firefox/html_struct_nav_links.py	(original)
+++ trunk/test/keystrokes/firefox/html_struct_nav_links.py	Wed Apr 30 19:18:31 2008
@@ -46,7 +46,6 @@
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("u"))
-sequence.append(WaitForFocus("anchors.html", acc_role=pyatspi.ROLE_LINK))
 sequence.append(utils.AssertPresentationAction(
     "u to anchors.html link", 
     ["BRAILLE LINE:  'â anchors.html Link'",
@@ -58,7 +57,6 @@
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("u"))
-sequence.append(WaitForFocus("blockquotes.html", acc_role=pyatspi.ROLE_LINK))
 sequence.append(utils.AssertPresentationAction(
     "u to blockquotes.html link", 
     ["BRAILLE LINE:  'â blockquotes.html Link'",
@@ -70,7 +68,6 @@
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Shift>u"))
-sequence.append(WaitForFocus("anchors.html", acc_role=pyatspi.ROLE_LINK))
 sequence.append(utils.AssertPresentationAction(
     "shift + u to anchors.html link", 
     ["BRAILLE LINE:  'â anchors.html Link'",
@@ -85,7 +82,6 @@
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Shift>u"))
-sequence.append(WaitForFocus("textattributes.html", acc_role=pyatspi.ROLE_LINK))
 sequence.append(utils.AssertPresentationAction(
     "shift + u wrapping to bottom",
     ["BRAILLE LINE:  'â textattributes.html Link'",
@@ -98,7 +94,6 @@
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Shift>u"))
-sequence.append(WaitForFocus("tables.html", acc_role=pyatspi.ROLE_LINK))
 sequence.append(utils.AssertPresentationAction(
     "shift + u to tables.html",
     ["BRAILLE LINE:  'â tables.html Link'",
@@ -122,7 +117,6 @@
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("u"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LINK))
 sequence.append(utils.AssertPresentationAction(
     "u to anchors.html link", 
     ["BRAILLE LINE:  'â anchors.html Link'",
@@ -134,7 +128,6 @@
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("u"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LINK))
 sequence.append(utils.AssertPresentationAction(
     "u to blockquotes.html link", 
     ["BRAILLE LINE:  'â blockquotes.html Link'",
@@ -158,7 +151,6 @@
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("v"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LINK))
 sequence.append(utils.AssertPresentationAction(
     "v to blockquotes.html link", 
     ["BRAILLE LINE:  'â blockquotes.html Link'",
@@ -170,7 +162,6 @@
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("v"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LINK))
 sequence.append(utils.AssertPresentationAction(
     "v to tables.html link", 
     ["BRAILLE LINE:  'â tables.html Link'",
@@ -182,7 +173,6 @@
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("v"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LINK))
 sequence.append(utils.AssertPresentationAction(
     "v to blockquotes.html link", 
     ["BRAILLE LINE:  'â blockquotes.html Link'",
@@ -195,7 +185,6 @@
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("<Shift>v"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LINK))
 sequence.append(utils.AssertPresentationAction(
     "shift + v to tables.html link", 
     ["BRAILLE LINE:  'â tables.html Link'",

Modified: trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py
==============================================================================
--- trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py	(original)
+++ trunk/test/keystrokes/firefox/label_guess_bugzilla_search.py	Wed Apr 30 19:18:31 2008
@@ -47,7 +47,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'Summary: contains all of the words/strings Combo  $l Search Button'",
@@ -112,7 +111,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST_ITEM))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  '0.0.1 List'",
@@ -124,7 +122,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST_ITEM))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  '--- List'",
@@ -168,7 +165,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'Whiteboard: contains all of the words/strings Combo  $l'",
@@ -179,7 +175,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'Keywords Link : contains all of the keywords Combo  $l'",
@@ -202,7 +197,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST_ITEM))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'UNCONFIRMED List'",
@@ -214,7 +208,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST_ITEM))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'FIXED List'",
@@ -226,7 +219,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST_ITEM))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'blocker List'",
@@ -238,7 +230,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST_ITEM))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'Immediate List'",
@@ -250,7 +241,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST_ITEM))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'All List'",
@@ -312,7 +302,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'contains Combo'",
@@ -324,7 +313,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  ' $l'",
@@ -385,7 +373,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'contains Combo'",
@@ -408,7 +395,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'Only include Combo bugs numbered:  $l'",
@@ -453,7 +439,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST_ITEM))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  '[Bug creation] List'",
@@ -476,7 +461,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST_ITEM))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'Unspecified List'",
@@ -488,7 +472,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_LIST_ITEM))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  'Unspecified List'",
@@ -500,7 +483,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(PauseAction(1000))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
@@ -543,7 +525,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  '--- Combo --- Combo  $l Or Button'",
@@ -555,7 +536,6 @@
 sequence.append(KeyPressAction(0, None, "KP_Insert"))
 sequence.append(KeyComboAction("Tab"))
 sequence.append(KeyReleaseAction(0, None, "KP_Insert"))
-sequence.append(WaitForFocus("", acc_role=pyatspi.ROLE_COMBO_BOX))
 sequence.append(utils.AssertPresentationAction(
     "Next form field", 
     ["BRAILLE LINE:  '--- Combo --- Combo  $l Or Button'",

Modified: trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_bugzilla_search.py	Wed Apr 30 19:18:31 2008
@@ -54,8 +54,15 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'Short Bug Search Form Link Complicated Bug Search Form'",
+    ["BUG? - For some reason we're getting the page load information",
+     "BRAILLE LINE:  'Short Bug Search Form Link Complicated Bug Search Form'",
+     "     VISIBLE:  'Short Bug Search Form Link Compl', cursor=0",
+     "BRAILLE LINE:  'Search for bugs'",
+     "     VISIBLE:  'Search for bugs', cursor=0",
+     "BRAILLE LINE:  'Short Bug Search Form Link Complicated Bug Search Form'",
      "     VISIBLE:  'Short Bug Search Form Link Compl', cursor=0",
+     "SPEECH OUTPUT: 'Â Short Bug Search Form link Complicated Bug Search Form Â'",
+     "SPEECH OUTPUT: 'Search for bugs page'",
      "SPEECH OUTPUT: 'Â Short Bug Search Form link Complicated Bug Search Form Â'"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/line_nav_empty_anchor.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_empty_anchor.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_empty_anchor.py	Wed Apr 30 19:18:31 2008
@@ -49,9 +49,14 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'Battery h2'",
+    ["BUG? - For some reason, we're repeating ourselves",
+     "BRAILLE LINE:  'Battery h2'",
+     "     VISIBLE:  'Battery h2', cursor=1",
+     "BRAILLE LINE:  'Battery h2'",
      "     VISIBLE:  'Battery h2', cursor=1",
      "SPEECH OUTPUT: 'Battery heading  '",
+     "SPEECH OUTPUT: 'level 2'",
+     "SPEECH OUTPUT: 'Battery heading  '",
      "SPEECH OUTPUT: 'level 2'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -119,8 +124,8 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  ' h2'",
-     "     VISIBLE:  ' h2', cursor=1",
+    ["BRAILLE LINE:  ''",
+     "     VISIBLE:  '', cursor=0",
      "SPEECH OUTPUT: '",
      " heading  '",
      "SPEECH OUTPUT: 'level 2'"]))

Modified: trunk/test/keystrokes/firefox/line_nav_enter_bug.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_enter_bug.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_enter_bug.py	Wed Apr 30 19:18:31 2008
@@ -72,8 +72,9 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'reported bugs Link , and please search Link  or browse Link  for the bug.'",
-     "     VISIBLE:  'reported bugs Link , and please ', cursor=1",
+    ["BUG? - We're missing some info in braille",
+     "BRAILLE LINE:  'reported bugs Link  search Link  browse Link '",
+     "     VISIBLE:  'reported bugs Link  search Link ', cursor=1",
      "SPEECH OUTPUT: 'reported bugs link , and please search link  or browse link  for the bug.'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -112,8 +113,9 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'version Link :'",
-     "     VISIBLE:  'version Link :', cursor=1",
+    ["BUG? - We're missing the colon in the braille",
+     "BRAILLE LINE:  'version Link '",
+     "     VISIBLE:  'version Link ', cursor=1",
      "SPEECH OUTPUT: 'version link :'"]))
 
 sequence.append(utils.StartRecordingAction())
@@ -395,8 +397,9 @@
 sequence.append(KeyComboAction("Up"))
 sequence.append(utils.AssertPresentationAction(
     "Line Up",
-    ["BRAILLE LINE:  'reported bugs Link , and please search Link  or browse Link  for the bug.'",
-     "     VISIBLE:  'reported bugs Link , and please ', cursor=1",
+    ["BUG? - We're missing some info in braille",
+     "BRAILLE LINE:  'reported bugs Link  search Link  browse Link '",
+     "     VISIBLE:  'reported bugs Link  search Link ', cursor=1",
      "SPEECH OUTPUT: 'reported bugs link , and please search link  or browse link  for the bug.'"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/line_nav_heading_section.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_heading_section.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_heading_section.py	Wed Apr 30 19:18:31 2008
@@ -48,9 +48,14 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'Heading 2. h1'",
+    ["BUG? - For some reason we're repeating ourselves",
+     "BRAILLE LINE:  'Heading 2. h1'",
+     "     VISIBLE:  'Heading 2. h1', cursor=1",
+     "BRAILLE LINE:  'Heading 2. h1'",
      "     VISIBLE:  'Heading 2. h1', cursor=1",
      "SPEECH OUTPUT: 'Heading 2. heading  '",
+     "SPEECH OUTPUT: 'level 1'",
+     "SPEECH OUTPUT: 'Heading 2. heading  '",
      "SPEECH OUTPUT: 'level 1'"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/line_nav_imagemap.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_imagemap.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_imagemap.py	Wed Apr 30 19:18:31 2008
@@ -47,8 +47,12 @@
 sequence.append(PauseAction(1000))
 sequence.append(utils.AssertPresentationAction(
     "1. line Down",
-    ["BRAILLE LINE:  'Test: z Link y Link x Link w Link v Link u Link t Link s Link r Link q Link p Link o Link n Link m Link l Link k Link j Link i Link h Link g Link f Link e Link d Link c Link b Link a Link'",
+    ["BUG? - For some reason we're repeating ourselves",
+     "BRAILLE LINE:  'Test: z Link y Link x Link w Link v Link u Link t Link s Link r Link q Link p Link o Link n Link m Link l Link k Link j Link i Link h Link g Link f Link e Link d Link c Link b Link a Link'",
+     "     VISIBLE:  'Test: z Link y Link x Link w Lin', cursor=1",
+     "BRAILLE LINE:  'Test: z Link y Link x Link w Link v Link u Link t Link s Link r Link q Link p Link o Link n Link m Link l Link k Link j Link i Link h Link g Link f Link e Link d Link c Link b Link a Link'",
      "     VISIBLE:  'Test: z Link y Link x Link w Lin', cursor=1",
+     "SPEECH OUTPUT: 'Test: z link y link x link w link v link u link t link s link r link q link p link o link n link m link l link k link j link i link h link g link f link e link d link c link b link a link'",
      "SPEECH OUTPUT: 'Test: z link y link x link w link v link u link t link s link r link q link p link o link n link m link l link k link j link i link h link g link f link e link d link c link b link a link'"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/line_nav_multi_line_text.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_multi_line_text.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_multi_line_text.py	Wed Apr 30 19:18:31 2008
@@ -47,8 +47,12 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'foo bar'",
+    ["BUG? - For some reason, we're repeating ourselves",
+     "BRAILLE LINE:  'foo bar'",
+     "     VISIBLE:  'foo bar', cursor=1",
+     "BRAILLE LINE:  'foo bar'",
      "     VISIBLE:  'foo bar', cursor=1",
+     "SPEECH OUTPUT: 'foo bar'",
      "SPEECH OUTPUT: 'foo bar'"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/line_nav_nested_tables.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_nested_tables.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_nested_tables.py	Wed Apr 30 19:18:31 2008
@@ -64,8 +64,12 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "3. line Down",
-    ["BRAILLE LINE:  'Below is a list of the courses that make up your learning plan.'",
+    ["BUG? - For some reason we're repeating ourselves",
+     "BRAILLE LINE:  'Below is a list of the courses that make up your learning plan.'",
+     "     VISIBLE:  'Below is a list of the courses t', cursor=1",
+     "BRAILLE LINE:  'Below is a list of the courses that make up your learning plan.'",
      "     VISIBLE:  'Below is a list of the courses t', cursor=1",
+     "SPEECH OUTPUT: 'Below is a list of the courses that make up your learning plan.'",
      "SPEECH OUTPUT: 'Below is a list of the courses that make up your learning plan.'"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/line_nav_simple_form.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_simple_form.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_simple_form.py	Wed Apr 30 19:18:31 2008
@@ -46,8 +46,12 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "1. line Down",
-    ["BRAILLE LINE:  'Magic disappearing text trick: tab to me and I disappear $l'",
+    ["BUG? - For some reason we're repeating ourselves",
+     "BRAILLE LINE:  'Magic disappearing text trick: tab to me and I disappear $l'",
+     "     VISIBLE:  'Magic disappearing text trick: t', cursor=1",
+     "BRAILLE LINE:  'Magic disappearing text trick: tab to me and I disappear $l'",
      "     VISIBLE:  'Magic disappearing text trick: t', cursor=1",
+     "SPEECH OUTPUT: 'Magic disappearing text trick: text tab to me and I disappear'",
      "SPEECH OUTPUT: 'Magic disappearing text trick: text tab to me and I disappear'"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/line_nav_table_cell_links.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_table_cell_links.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_table_cell_links.py	Wed Apr 30 19:18:31 2008
@@ -47,9 +47,14 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'HTML Tags'",
+    ["BUG? - For some reason, we're repeating ourselves",
+     "BRAILLE LINE:  'HTML Tags'",
+     "     VISIBLE:  'HTML Tags', cursor=1",
+     "BRAILLE LINE:  'HTML Tags'",
      "     VISIBLE:  'HTML Tags', cursor=1",
      "SPEECH OUTPUT: 'HTML Tags",
+     "'",
+     "SPEECH OUTPUT: 'HTML Tags",
      "'"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/line_nav_wiki.py
==============================================================================
--- trunk/test/keystrokes/firefox/line_nav_wiki.py	(original)
+++ trunk/test/keystrokes/firefox/line_nav_wiki.py	Wed Apr 30 19:18:31 2008
@@ -51,10 +51,16 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Line Down",
-    ["BRAILLE LINE:  'live.gnome.org h1 Search $l Titles Button Text Button'",
+    ["BUG? - For some reason, we're repeating ourselves",
+     "BRAILLE LINE:  'live.gnome.org h1 Search $l Titles Button Text Button'",
+     "     VISIBLE:  'live.gnome.org h1 Search $l Titl', cursor=1",
+     "BRAILLE LINE:  'live.gnome.org h1 Search $l Titles Button Text Button'",
      "     VISIBLE:  'live.gnome.org h1 Search $l Titl', cursor=1",
      "SPEECH OUTPUT: 'live.gnome.org heading  '",
      "SPEECH OUTPUT: 'level 1'",
+     "SPEECH OUTPUT: 'text Search Titles button grayed Text button grayed'",
+     "SPEECH OUTPUT: 'live.gnome.org heading  '",
+     "SPEECH OUTPUT: 'level 1'",
      "SPEECH OUTPUT: 'text Search Titles button grayed Text button grayed'"]))
 
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/moz_menu.py
==============================================================================
--- trunk/test/keystrokes/firefox/moz_menu.py	(original)
+++ trunk/test/keystrokes/firefox/moz_menu.py	Wed Apr 30 19:18:31 2008
@@ -66,12 +66,12 @@
      "SPEECH OUTPUT: 'View'"]))
     
 sequence.append(utils.StartRecordingAction())
+sequence.append(PauseAction(2000))
 sequence.append(KeyComboAction("Down"))
-sequence.append(PauseAction(1000))
 sequence.append(utils.AssertPresentationAction(
     "Move to Themes", 
     ["BRAILLE LINE:  'Themes ÂÂ Â ÂÂ Â>'",
-     "     VISIBLE:  'Themes ÂÂ Â ÂÂ Â>', cursor=1",
+     "     VISIBLE:  'Themes ÂÂ Â ÂÂ Â>', cursor=0",
      "BRAILLE LINE:  'Themes ÂÂ Â ÂÂ Â>'",
      "     VISIBLE:  'Themes ÂÂ Â ÂÂ Â>', cursor=1",
      "SPEECH OUTPUT: ''",
@@ -80,12 +80,12 @@
      "SPEECH OUTPUT: 'Themes ÂÂ Â ÂÂ Â>'"]))
 
 sequence.append(utils.StartRecordingAction())
+sequence.append(PauseAction(2000))
 sequence.append(KeyComboAction("Right"))
-sequence.append(PauseAction(1000))
 sequence.append(utils.AssertPresentationAction(
     "Move to basic grey", 
     ["BRAILLE LINE:  'Basic Grey'",
-     "     VISIBLE:  'Basic Grey', cursor=1",
+     "     VISIBLE:  'Basic Grey', cursor=0",
      "BRAILLE LINE:  'Basic Grey'",
      "     VISIBLE:  'Basic Grey', cursor=1",
      "SPEECH OUTPUT: ''",

Modified: trunk/test/keystrokes/firefox/moz_progressbar.py
==============================================================================
--- trunk/test/keystrokes/firefox/moz_progressbar.py	(original)
+++ trunk/test/keystrokes/firefox/moz_progressbar.py	Wed Apr 30 19:18:31 2008
@@ -144,15 +144,25 @@
 sequence.append(utils.AssertPresentationAction(
     "progress output", 
     ["BUG? - We're also speaking the progress bar number.  We weren't before.  Should we be?",
+     "SPEECH OUTPUT: 'Progress bar 2.'",
      "SPEECH OUTPUT: '10 percent. '",
+     "SPEECH OUTPUT: 'Progress bar 2.'",
      "SPEECH OUTPUT: '20 percent. '",
+     "SPEECH OUTPUT: 'Progress bar 2.'",
      "SPEECH OUTPUT: '30 percent. '",
+     "SPEECH OUTPUT: 'Progress bar 2.'",
      "SPEECH OUTPUT: '40 percent. '",
+     "SPEECH OUTPUT: 'Progress bar 2.'",
      "SPEECH OUTPUT: '50 percent. '",
+     "SPEECH OUTPUT: 'Progress bar 2.'",
      "SPEECH OUTPUT: '60 percent. '",
+     "SPEECH OUTPUT: 'Progress bar 2.'",
      "SPEECH OUTPUT: '70 percent. '",
+     "SPEECH OUTPUT: 'Progress bar 2.'",
      "SPEECH OUTPUT: '80 percent. '",
+     "SPEECH OUTPUT: 'Progress bar 2.'",
      "SPEECH OUTPUT: '90 percent. '",
+     "SPEECH OUTPUT: 'Progress bar 2.'",
      "SPEECH OUTPUT: '100 percent. '"]))
 
 ########################################################################

Modified: trunk/test/keystrokes/firefox/page_summary.py
==============================================================================
--- trunk/test/keystrokes/firefox/page_summary.py	(original)
+++ trunk/test/keystrokes/firefox/page_summary.py	Wed Apr 30 19:18:31 2008
@@ -35,6 +35,8 @@
     "Navigate to 'This is a Heading 6.'",
     ["BRAILLE LINE:  'This is a Heading 6. h6'",
      "     VISIBLE:  'This is a Heading 6. h6', cursor=1",
+     "BRAILLE LINE:  'This is a Heading 6. h6'",
+     "     VISIBLE:  'This is a Heading 6. h6', cursor=1",
      "SPEECH OUTPUT: 'This is a Heading 6. heading  '",
      "SPEECH OUTPUT: 'level 6'"]))
 
@@ -47,18 +49,19 @@
 sequence.append(PauseAction(30000))
 sequence.append(utils.AssertPresentationAction(
     "Where Am I for page summary info",
-    ["BUG? - Seems that we're no longer indicating the percent",
+    ["BUG? - Seems that we're no longer indicating the percent of document read",
      "BRAILLE LINE:  'This is a Heading 6. h6'",
      "     VISIBLE:  'This is a Heading 6. h6', cursor=1",
      "BRAILLE LINE:  'This is a Heading 6. h6'",
      "     VISIBLE:  'This is a Heading 6. h6', cursor=1",
-     "SPEECH OUTPUT: 'This is a Heading 6.'",
+     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'heading'",
+     "SPEECH OUTPUT: 'This is a Heading 6.'",
+     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: '14 headings'",
      "SPEECH OUTPUT: '3 forms'",
      "SPEECH OUTPUT: '47 tables'",
-     "SPEECH OUTPUT: '19 unvisited links'",
-     "SPEECH OUTPUT: '1 percent of document read'"]))
+     "SPEECH OUTPUT: '19 unvisited links'"]))
 
 ########################################################################
 # Close the demo

Modified: trunk/test/keystrokes/firefox/uiuc_button.py
==============================================================================
--- trunk/test/keystrokes/firefox/uiuc_button.py	(original)
+++ trunk/test/keystrokes/firefox/uiuc_button.py	Wed Apr 30 19:18:31 2008
@@ -31,12 +31,12 @@
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "tab to first button", 
-    ["BRAILLE LINE:  '& y Font Larger + ToggleButton'",
-     "     VISIBLE:  '& y Font Larger + ToggleButton', cursor=1",
-     "BRAILLE LINE:  '& y Font Larger + ToggleButton'",
-     "     VISIBLE:  '& y Font Larger + ToggleButton', cursor=1",
+    ["BRAILLE LINE:  'Font Larger + Button Font Smaller - Button & y Italic i ToggleButton Bold B Button'",
+     "     VISIBLE:  'Font Larger + Button Font Smalle', cursor=1",
+     "BRAILLE LINE:  'Font Larger + Button Font Smaller - Button & y Italic i ToggleButton Bold B Button'",
+     "     VISIBLE:  'Font Larger + Button Font Smalle', cursor=1",
      "SPEECH OUTPUT: 'Text Formating Controls 1 list'",
-     "SPEECH OUTPUT: 'Font Larger + toggle button not pressed'"]))
+     "SPEECH OUTPUT: 'Font Larger + button'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter.  The following should be
@@ -47,11 +47,11 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "basic whereamI", 
-    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton & y Bold B ToggleButton'",
-     "     VISIBLE:  '& y Font Larger + ToggleButton &', cursor=1",
+    ["BRAILLE LINE:  'Font Larger + Button Font Smaller - Button & y Italic i ToggleButton Bold B Button'",
+     "     VISIBLE:  'Font Larger + Button Font Smalle', cursor=1",
      "SPEECH OUTPUT: 'Font Larger +'",
-     "SPEECH OUTPUT: 'toggle button'",
-     "SPEECH OUTPUT: 'not pressed'"]))
+     "SPEECH OUTPUT: 'button'",
+     "SPEECH OUTPUT: ''"]))
 
 ########################################################################
 # Now push the first button.  The following will be presented.
@@ -70,12 +70,13 @@
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "tab to second button", 
-    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton & y Bold B ToggleButton'",
-     "     VISIBLE:  '& y Font Smaller - ToggleButton ', cursor=1",
-     "BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton & y Bold B ToggleButton'",
-     "     VISIBLE:  '& y Font Smaller - ToggleButton ', cursor=1",
+    ["BRAILLE LINE:  'Font Larger + Button Font Smaller - Button & y Italic i ToggleButton Bold B Button'",
+     "     VISIBLE:  'Font Smaller - Button & y Italic', cursor=1",
+     "BRAILLE LINE:  'Font Larger + Button Font Smaller - Button & y Italic i ToggleButton Bold B Button'",
+     "     VISIBLE:  'Font Smaller - Button & y Italic', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Font Smaller - toggle button not pressed'"]))
+     "SPEECH OUTPUT: 'Font Smaller - button'"]))
+
 ########################################################################
 # Now push the second button.  The following will be presented.
 #
@@ -92,12 +93,13 @@
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "tab to third button", 
-    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton & y Bold B ToggleButton'",
-     "     VISIBLE:  '& y Italic i ToggleButton & y Bo', cursor=1",
-     "BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton & y Bold B ToggleButton'",
-     "     VISIBLE:  '& y Italic i ToggleButton & y Bo', cursor=1",
+    ["BRAILLE LINE:  'Font Larger + Button Font Smaller - Button & y Italic i ToggleButton Bold B Button'",
+     "     VISIBLE:  '& y Italic i ToggleButton Bold B', cursor=1",
+     "BRAILLE LINE:  'Font Larger + Button Font Smaller - Button & y Italic i ToggleButton Bold B Button'",
+     "     VISIBLE:  '& y Italic i ToggleButton Bold B', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Italic i toggle button not pressed'"]))
+
 ########################################################################
 # Now push the third button.  The following will be presented.
 #
@@ -114,12 +116,13 @@
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "tab to fourth button", 
-    ["BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton & y Bold B ToggleButton'",
-     "     VISIBLE:  '& y Bold B ToggleButton', cursor=1",
-     "BRAILLE LINE:  '& y Font Larger + ToggleButton & y Font Smaller - ToggleButton & y Italic i ToggleButton & y Bold B ToggleButton'",
-     "     VISIBLE:  '& y Bold B ToggleButton', cursor=1",
+    ["BRAILLE LINE:  'Font Larger + Button Font Smaller - Button & y Italic i ToggleButton Bold B Button'",
+     "     VISIBLE:  'Bold B Button', cursor=1",
+     "BRAILLE LINE:  'Font Larger + Button Font Smaller - Button & y Italic i ToggleButton Bold B Button'",
+     "     VISIBLE:  'Bold B Button', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Bold B toggle button not pressed'"]))
+     "SPEECH OUTPUT: 'Bold B button'"]))
+
 ########################################################################
 # Now push the fourth button.  The following will be presented.
 #

Modified: trunk/test/keystrokes/firefox/uiuc_grid.py
==============================================================================
--- trunk/test/keystrokes/firefox/uiuc_grid.py	(original)
+++ trunk/test/keystrokes/firefox/uiuc_grid.py	Wed Apr 30 19:18:31 2008
@@ -23,6 +23,7 @@
 sequence.append(KeyComboAction("Return"))
 sequence.append(WaitForDocLoad())
 
+sequence.append(PauseAction(3000))
 
 ########################################################################
 # Tab to grid
@@ -35,8 +36,6 @@
      "     VISIBLE:  'E-mail List Sorted by Date Capti', cursor=0",
      "BRAILLE LINE:  '< > Email 0 Selected CheckBox 1 Cell Read message Image Attachment Image Lowest priority Image John Smith Cell Trip to Florida Cell 2007-10-03 Cell 2K Cell'",
      "     VISIBLE:  '< > Email 0 Selected CheckBox 1 ', cursor=1",
-     "BRAILLE LINE:  '< > Email 0 Selected CheckBox 1 Cell Read message Image Attachment Image Lowest priority Image John Smith Cell Trip to Florida Cell 2007-10-03 Cell 2K Cell'",
-     "     VISIBLE:  '< > Email 0 Selected CheckBox 1 ', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'E-mail List Sorted by Date table'",
      "SPEECH OUTPUT: ''",

Modified: trunk/test/keystrokes/firefox/uiuc_tree.py
==============================================================================
--- trunk/test/keystrokes/firefox/uiuc_tree.py	(original)
+++ trunk/test/keystrokes/firefox/uiuc_tree.py	Wed Apr 30 19:18:31 2008
@@ -24,9 +24,11 @@
 sequence.append(WaitForDocLoad())
 sequence.append(WaitForFocus("inline: Tree Example 1", acc_role=pyatspi.ROLE_DOCUMENT_FRAME))
 
+sequence.append(PauseAction(5000))
+
 ########################################################################
 # Tab to the tree.  
-#[[[Bug?: repeated Braille]]]
+#
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Tab"))
 sequence.append(WaitForFocus("Fruits", acc_role=pyatspi.ROLE_LIST_ITEM))
@@ -36,8 +38,6 @@
      "     VISIBLE:  'Fruits ListItem', cursor=1",
      "BRAILLE LINE:  'Fruits ListItem'",
      "     VISIBLE:  'Fruits ListItem', cursor=1",
-     "BRAILLE LINE:  'Fruits ListItem'",
-     "     VISIBLE:  'Fruits ListItem', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Foods tree'",
      "SPEECH OUTPUT: ''",
@@ -198,9 +198,9 @@
 sequence.append(KeyComboAction("Left"))
 sequence.append(utils.AssertPresentationAction(
     "collapse vegetables", 
-    ["[[[Bug: list and panel should probably not be output]]]",
-     "BRAILLE LINE:  'Vegetables ListItem'",
-     "     VISIBLE:  'Vegetables ListItem', cursor=1",
+    ["Bug? - list and panel should probably not be output",
+     "BRAILLE LINE:  'Vegetables ListItem Panel List'",
+     "     VISIBLE:  'Vegetables ListItem Panel List', cursor=1",
      "SPEECH OUTPUT: 'collapsed'"]))
 
 ########################################################################

Modified: trunk/test/keystrokes/firefox/xul_role_alert.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_alert.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_alert.py	Wed Apr 30 19:18:31 2008
@@ -40,7 +40,6 @@
      "SPEECH OUTPUT: 'about:blank html content'",
      "SPEECH OUTPUT: 'about:blank page'",
      "SPEECH OUTPUT: 'about:blank html content'",
-     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: '[JavaScript Application] I am an alert'",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'OK button'"]))

Modified: trunk/test/keystrokes/firefox/xul_role_combo_box.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_combo_box.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_combo_box.py	Wed Apr 30 19:18:31 2008
@@ -44,7 +44,7 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Down Arrow in combobox",
-    ["BRAILLE LINE:  'Minefield Application Minefield Preferences Frame Main ScrollPane Startup Panel  ComboShow my windows and tabs from last timeWhen Minefield starts:  Show my windows and tabs from last time'",
+    ["BRAILLE LINE:  'Minefield Application Minefield Preferences Frame Main ScrollPane Startup Panel  ComboShow my windows and tabs from last timeWhen Minefield starts:  Show a blank page'",
      "     VISIBLE:  'Show a blank page', cursor=1",
      "BRAILLE LINE:  'Minefield Application Minefield Preferences Frame Main ScrollPane Startup Panel  ComboShow my windows and tabs from last timeWhen Minefield starts:  Show my windows and tabs from last time'",
      "     VISIBLE:  'Show my windows and tabs from la', cursor=1",
@@ -144,7 +144,7 @@
     "First letter navigation with s",
     ["BRAILLE LINE:  'Minefield Application Minefield Preferences Frame Main ScrollPane Startup Panel  ComboShow my home pageWhen Minefield starts:  Show a blank page'",
      "     VISIBLE:  'Show a blank page', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Minefield Preferences Frame Main ScrollPane Startup Panel  ComboShow my home pageWhen Minefield starts:  Show a blank page'",
+     "BRAILLE LINE:  'Minefield Application Minefield Preferences Frame Main ScrollPane Startup Panel  ComboShow my home pageWhen Minefield starts:  Show my home page'",
      "     VISIBLE:  'Show my home page', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Show a blank page'",
@@ -171,7 +171,7 @@
     ["BUG? -  Techically the parent of the focused menu item (what combo boxes contain) is a menu, but in this case we presumably want to indicate that the focused item is a combo box.",
      "BRAILLE LINE:  'Minefield Application Minefield Preferences Frame Main ScrollPane Startup Panel  ComboShow a blank pageWhen Minefield starts:  Show a blank page'",
      "     VISIBLE:  'Show a blank page', cursor=1",
-     "SPEECH OUTPUT: 'Show my windows and tabs from last time menu'",
+     "SPEECH OUTPUT: 'Show a blank page menu'",
      "SPEECH OUTPUT: 'Show a blank page'",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'item 1 of 1'",

Modified: trunk/test/keystrokes/firefox/xul_role_entry.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_list_item.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_list_item.py	Wed Apr 30 19:18:31 2008
@@ -38,11 +38,11 @@
 sequence.append(KeyComboAction("Right"))
 sequence.append(utils.AssertPresentationAction(
     "Right Arrow in list",
-    ["BUG? - Extra stuff is being spoken",
-     "BRAILLE LINE:  'Minefield Application Minefield Preferences Frame List Content ListItem'",
+    ["BRAILLE LINE:  'Minefield Application Minefield Preferences Frame List Content ListItem'",
      "     VISIBLE:  'Content ListItem', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Content list item'"]))
+     "SPEECH OUTPUT: 'Content list item'",
+     "SPEECH OUTPUT: 'Size:'"]))
 
 ########################################################################
 # Press Left Arrow to move backward list item by list item.

Modified: trunk/test/keystrokes/firefox/xul_role_menu_bar.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_menu_bar.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_menu_bar.py	Wed Apr 30 19:18:31 2008
@@ -85,7 +85,7 @@
      "     VISIBLE:  'Location  $l', cursor=10",
      "BRAILLE LINE:  'Minefield Application Minefield Frame ToolBar Application MenuBar Toolbars Menu'",
      "     VISIBLE:  'Toolbars Menu', cursor=1",
-     "SPEECH OUTPUT: 'Location autocomplete'",
+     "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Location text '",
      "SPEECH OUTPUT: 'View menu'",
      "SPEECH OUTPUT: 'Toolbars menu'",]))

Modified: trunk/test/keystrokes/firefox/xul_role_page_tab.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_page_tab.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_page_tab.py	Wed Apr 30 19:18:31 2008
@@ -34,7 +34,7 @@
      "     VISIBLE:  'General Page', cursor=1",
      "SPEECH OUTPUT: 'tab list'",
      "SPEECH OUTPUT: 'General page'",
-     "SPEECH OUTPUT: 'item 1 of 6'",
+     "SPEECH OUTPUT: 'item 1 of [0-9]+'",
      "SPEECH OUTPUT: ''"]))
 
 ########################################################################
@@ -61,7 +61,7 @@
      "     VISIBLE:  'Page Setup Page', cursor=1",
      "SPEECH OUTPUT: 'tab list'",
      "SPEECH OUTPUT: 'Page Setup page'",
-     "SPEECH OUTPUT: 'item 2 of 6'",
+     "SPEECH OUTPUT: 'item 2 of [0-9]+'",
      "SPEECH OUTPUT: ''"]))
 
 ########################################################################

Modified: trunk/test/keystrokes/firefox/xul_role_radio_button.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_radio_button.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_radio_button.py	Wed Apr 30 19:18:31 2008
@@ -28,10 +28,10 @@
 sequence.append(KeyComboAction("<Alt>a"))
 sequence.append(utils.AssertPresentationAction(
     "Alt a to radio button group",
-    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Range Filler &=y All Pages RadioButton'",
-     "     VISIBLE:  '&=y All Pages RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Range'",
-     "SPEECH OUTPUT: 'All Pages selected radio button'"]))
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Print Pages Filler &=y All RadioButton'",
+     "     VISIBLE:  '&=y All RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'Print Pages'",
+     "SPEECH OUTPUT: 'All selected radio button'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter. 
@@ -41,10 +41,10 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Range Filler &=y All Pages RadioButton'",
-     "     VISIBLE:  '&=y All Pages RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Range'",
-     "SPEECH OUTPUT: 'All Pages radio button'",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Print Pages Filler &=y All RadioButton'",
+     "     VISIBLE:  '&=y All RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'Print Pages'",
+     "SPEECH OUTPUT: 'All radio button'",
      "SPEECH OUTPUT: 'selected'",
      "SPEECH OUTPUT: 'item 1 of 3'",
      "SPEECH OUTPUT: 'Alt a'"]))
@@ -56,10 +56,10 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Down Arrow to next radio button",
-    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Range Filler & y Pages: RadioButton'",
-     "     VISIBLE:  '& y Pages: RadioButton', cursor=1",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Print Pages Filler & y Range RadioButton'",
+     "     VISIBLE:  '& y Range RadioButton', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Pages: not selected radio button'"]))
+     "SPEECH OUTPUT: 'Range not selected radio button'"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter. 
@@ -69,13 +69,13 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Range Filler &=y Pages: RadioButton'",
-     "     VISIBLE:  '&=y Pages: RadioButton', cursor=1",
-     "SPEECH OUTPUT: 'Range'",
-     "SPEECH OUTPUT: 'Pages: radio button'",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page Print Pages Filler &=y Range RadioButton'",
+     "     VISIBLE:  '&=y Range RadioButton', cursor=1",
+     "SPEECH OUTPUT: 'Print Pages'",
+     "SPEECH OUTPUT: 'Range radio button'",
      "SPEECH OUTPUT: 'selected'",
      "SPEECH OUTPUT: 'item 3 of 3'",
-     "SPEECH OUTPUT: 'Alt e'"]))
+     "SPEECH OUTPUT: 'Alt n'"]))
 
 ########################################################################
 # Dismiss the dialog by pressing Escape and wait for the location bar

Modified: trunk/test/keystrokes/firefox/xul_role_tree.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_tree_table.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_tree_table.py	Wed Apr 30 19:18:31 2008
@@ -50,12 +50,11 @@
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Down Arrow in tree table",
-    ["BRAILLE LINE:  'Minefield Application Library Frame ScrollPane TreeTable Name ColumnHeader Bookmarks Menu   TREE LEVEL 1'",
+    ["BUG? - We're not speaking the tree level",
+     "BRAILLE LINE:  'Minefield Application Library Frame ScrollPane TreeTable Name ColumnHeader Bookmarks Menu   TREE LEVEL 1'",
      "     VISIBLE:  'Bookmarks Menu   TREE LEVEL 1', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'Name column header'",
-     "SPEECH OUTPUT: 'Bookmarks Menu  '",
-     "SPEECH OUTPUT: 'tree level 1'"]))
+     "SPEECH OUTPUT: 'Bookmarks Menu  '"]))
 
 ########################################################################
 # Do a basic "Where Am I" via KP_Enter. 
@@ -65,13 +64,14 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Library Frame ScrollPane TreeTable     TREE LEVEL 1'",
-     "     VISIBLE:  'Minefield Application Library Fr', cursor=0",
+    ["BRAILLE LINE:  'Minefield Application Library Frame ScrollPane TreeTable Name ColumnHeader Bookmarks Menu TREE LEVEL 1'",
+     "     VISIBLE:  'Bookmarks Menu TREE LEVEL 1', cursor=1",
      "SPEECH OUTPUT: 'tree table'",
      "SPEECH OUTPUT: 'Name'",
      "SPEECH OUTPUT: 'cell'",
      "SPEECH OUTPUT: 'Bookmarks Menu'",
-     "SPEECH OUTPUT: 'row 1 of 3'",
+     "SPEECH OUTPUT: 'column 1 of 3',
+     "SPEECH OUTPUT: 'row 2 of 3'",
      "SPEECH OUTPUT: 'tree level 1'"]))
 
 ########################################################################

Modified: trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py	(original)
+++ trunk/test/keystrokes/firefox/xul_where_am_i_dialog.py	Wed Apr 30 19:18:31 2008
@@ -55,10 +55,10 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Default button", 
-    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page ScrollPane Table '",
-     "     VISIBLE:  '', cursor=1",
-     "BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page ScrollPane Table '",
-     "     VISIBLE:  '', cursor=1",
+    ["BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page ScrollPane Table  PDF  '",
+     "     VISIBLE:  ' PDF  ', cursor=1",
+     "BRAILLE LINE:  'Minefield Application Print Dialog TabList General Page ScrollPane Table  PDF  '",
+     "     VISIBLE:  ' PDF  ', cursor=1",
      "SPEECH OUTPUT: 'Print'",
      "SPEECH OUTPUT: 'Default button is Print'"]))
 

Modified: trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py	(original)
+++ trunk/test/keystrokes/firefox/xul_where_am_i_status_bar.py	Wed Apr 30 19:18:31 2008
@@ -70,7 +70,7 @@
      "     VISIBLE:  'Who expects the Spanish Inquisit', cursor=1",
      "BRAILLE LINE:  'Who expects the Spanish Inquisition? Button'",
      "     VISIBLE:  'Who expects the Spanish Inquisit', cursor=1",
-     "SPEECH OUTPUT: 'Minefield'",
+     "SPEECH OUTPUT: 'Status Bar Regression Test - Minefield'",
      "SPEECH OUTPUT: 'NOBODY expects the Spanish Inquisition!'",
      "SPEECH OUTPUT: ''"]))
 



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
--- trunk/test/keystrokes/firefox/xul_role_entry.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_entry.py	Wed Apr 30 19:18:31 2008
@@ -15,7 +15,7 @@
 sequence.append(WaitForWindowActivate("Minefield",None))
 
 ########################################################################
-# Open the "Bookmarks" menu, Down Arrow to Show All Bookmarks, then 
+# Open the "Bookmarks" menu, Down Arrow to Organize Bookmarks, then 
 # press Return.
 #
 sequence.append(KeyComboAction("<Alt>b"))
@@ -23,10 +23,15 @@
 sequence.append(KeyComboAction("Return"))
 
 ########################################################################
-# Down Arrow to select Bookmarks menu (necessary to add a new item).
-# Then Press Alt+O for Organize and Return on "New Bookmark..."
-#
-sequence.append(KeyComboAction("Down", 3000))
+# Tab three times, then down arrow twice to Bookmarks Menu. (This is
+# necessary to add a new item).  Then Press Alt+O for Organize and Return
+# on "New Bookmark..."
+#
+sequence.append(KeyComboAction("Tab", 1000))
+sequence.append(KeyComboAction("Tab", 1000))
+sequence.append(KeyComboAction("Tab", 1000))
+sequence.append(KeyComboAction("Down", 1000))
+sequence.append(KeyComboAction("Down", 1000))
 sequence.append(KeyComboAction("<Alt>o"))
 sequence.append(KeyComboAction("Return", 1000))
 
@@ -313,40 +318,40 @@
 sequence.append(utils.AssertPresentationAction(
     "Delete",
     ["BRAILLE LINE:  'Minefield Application Add Bookmark Dialog  this $l'",
-     "     VISIBLE:  ' this $l', cursor=2",
-     "SPEECH OUTPUT: 't'"]))
+     "     VISIBLE:  ' this $l', cursor=1",
+     "SPEECH OUTPUT: ' '"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Delete", 500))
 sequence.append(utils.AssertPresentationAction(
     "Delete",
     ["BRAILLE LINE:  'Minefield Application Add Bookmark Dialog this $l'",
-     "     VISIBLE:  'this $l', cursor=2",
-     "SPEECH OUTPUT: 'h'"]))
+     "     VISIBLE:  'this $l', cursor=1",
+     "SPEECH OUTPUT: 't'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Delete", 500))
 sequence.append(utils.AssertPresentationAction(
     "Delete",
     ["BRAILLE LINE:  'Minefield Application Add Bookmark Dialog his $l'",
-     "     VISIBLE:  'his $l', cursor=2",
-     "SPEECH OUTPUT: 'i'"]))
+     "     VISIBLE:  'his $l', cursor=1",
+     "SPEECH OUTPUT: 'h'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Delete", 500))
 sequence.append(utils.AssertPresentationAction(
     "Delete",
     ["BRAILLE LINE:  'Minefield Application Add Bookmark Dialog is $l'",
-     "     VISIBLE:  'is $l', cursor=2",
-     "SPEECH OUTPUT: 's'"]))
+     "     VISIBLE:  'is $l', cursor=1",
+     "SPEECH OUTPUT: 'i'"]))
 
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Delete", 500))
 sequence.append(utils.AssertPresentationAction(
     "Delete",
     ["BRAILLE LINE:  'Minefield Application Add Bookmark Dialog s $l'",
-     "     VISIBLE:  's $l', cursor=2",
-     "SPEECH OUTPUT: ''"]))
+     "     VISIBLE:  's $l', cursor=1",
+     "SPEECH OUTPUT: 's'"]))
 
 ########################################################################
 # Press Tab to get to the Location entry.

Modified: trunk/test/keystrokes/firefox/xul_role_list_item.py
==============================================================================
--- trunk/test/keystrokes/firefox/xul_role_tree.py	(original)
+++ trunk/test/keystrokes/firefox/xul_role_tree.py	Wed Apr 30 19:18:31 2008
@@ -54,8 +54,7 @@
      "BRAILLE LINE:  'Minefield Application Library Frame Tree All Bookmarks ListItem'",
      "     VISIBLE:  'All Bookmarks ListItem', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'All Bookmarks list item expanded'",
-     "SPEECH OUTPUT: 'tree level 1'"]))
+     "SPEECH OUTPUT: 'All Bookmarks list item expanded'"]))
 
 ########################################################################
 # Press Down Arrow twice to give focus to the Bookmarks Menu list item.
@@ -91,7 +90,7 @@
      "     VISIBLE:  'Bookmarks Menu ListItem', cursor=1",
      "SPEECH OUTPUT: 'list item'",
      "SPEECH OUTPUT: 'Bookmarks Menu'",
-     "SPEECH OUTPUT: 'item 2 of 4'",
+     "SPEECH OUTPUT: 'item 2 of 3'",
      "SPEECH OUTPUT: 'collapsed'",
      "SPEECH OUTPUT: 'tree level 2'"]))
 
@@ -118,22 +117,21 @@
      "     VISIBLE:  'Bookmarks Menu ListItem', cursor=1",
      "SPEECH OUTPUT: 'list item'",
      "SPEECH OUTPUT: 'Bookmarks Menu'",
-     "SPEECH OUTPUT: 'item 2 of 4'",
+     "SPEECH OUTPUT: 'item 2 of 3'",
      "SPEECH OUTPUT: 'expanded'",
      "SPEECH OUTPUT: 'tree level 2'"]))
 
 ########################################################################
 # Press Down Arrow to give focus to the next item, GNOME, which is not
 # expandable.
 #
 sequence.append(utils.StartRecordingAction())
 sequence.append(KeyComboAction("Down"))
 sequence.append(utils.AssertPresentationAction(
     "Down Arrow in tree",
-    ["BRAILLE LINE:  'Minefield Application Library Frame Tree GNOME ListItem'",
-     "     VISIBLE:  'GNOME ListItem', cursor=1",
+    ["BRAILLE LINE:  'Minefield Application Library Frame Tree Recently Bookmarked ListItem'",
+     "     VISIBLE:  'Recently Bookmarked ListItem', cursor=1",
      "SPEECH OUTPUT: ''",
-     "SPEECH OUTPUT: 'GNOME list item'",
+     "SPEECH OUTPUT: 'Recently Bookmarked list item'",
      "SPEECH OUTPUT: 'tree level 3'"]))
 
 ########################################################################
@@ -144,11 +142,11 @@
 sequence.append(PauseAction(3000))
 sequence.append(utils.AssertPresentationAction(
     "Basic Where Am I", 
-    ["BRAILLE LINE:  'Minefield Application Library Frame Tree GNOME ListItem'",
-     "     VISIBLE:  'GNOME ListItem', cursor=1",
+    ["BRAILLE LINE:  'Minefield Application Library Frame Tree Recently Bookmarked ListItem'",
+     "     VISIBLE:  'Recently Bookmarked ListItem', cursor=1",
      "SPEECH OUTPUT: 'list item'",
-     "SPEECH OUTPUT: 'GNOME'",
-     "SPEECH OUTPUT: 'item 1 of 2'",
+     "SPEECH OUTPUT: 'Recently Bookmarked'",
+     "SPEECH OUTPUT: 'item 1 of 4'",
      "SPEECH OUTPUT: 'tree level 3'"]))
 
 ########################################################################
@@ -204,11 +202,11 @@
 sequence.append(KeyComboAction("Tab"))
 sequence.append(utils.AssertPresentationAction(
     "Tab back to tree table",
-    ["BRAILLE LINE:  'Minefield Application Library Frame ScrollPane TreeTable   Bookmarks Menu  TREE LEVEL 1'",
-     "     VISIBLE:  'Minefield Application Library Fr', cursor=0",
+    ["BRAILLE LINE:  'Minefield Application Library Frame ScrollPane TreeTable Name ColumnHeader Bookmarks Toolbar   TREE LEVEL 1'",
+     "     VISIBLE:  'Bookmarks Toolbar   TREE LEVEL 1', cursor=1",
      "SPEECH OUTPUT: ''",
      "SPEECH OUTPUT: 'Name column header'",
-     "SPEECH OUTPUT: '  Bookmarks Menu '",
+     "SPEECH OUTPUT: 'Bookmarks Toolbar  '",
      "SPEECH OUTPUT: ' not selected'"]))
 
 ########################################################################
@@ -118,22 +117,21 @@
 
 ########################################################################
-# Press Down Arrow to give focus to the next item, GNOME, which is not
-# expandable.
+# Press Down Arrow to give focus to the next item, Recently Bookmarked.
 #
 sequence.append(utils.StartRecordingAction())

Modified: trunk/test/keystrokes/firefox/xul_role_tree_table.py
==============================================================================